@@ -549,15 +549,15 @@ class SlashMessage(ComponentMessage):
 
         allowed_mentions = fields.get("allowed_mentions")
         if allowed_mentions is not None:
-            if self.bot.allowed_mentions is not None:
-                _resp["allowed_mentions"] = self.bot.allowed_mentions.merge(
+            if self._state.allowed_mentions is not None:
+                _resp["allowed_mentions"] = self._state.allowed_mentions.merge(
                     allowed_mentions
                 ).to_dict()
             else:
                 _resp["allowed_mentions"] = allowed_mentions.to_dict()
         else:
-            if self.bot.allowed_mentions is not None:
-                _resp["allowed_mentions"] = self.bot.allowed_mentions.to_dict()
+            if self._state.allowed_mentions is not None:
+                _resp["allowed_mentions"] = self._state.allowed_mentions.to_dict()
             else:
                 _resp["allowed_mentions"] = {}
 
